@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::App;
 BEGIN {
-  $Class::Scaffold::App::VERSION = '1.101400';
+  $Class::Scaffold::App::VERSION = '1.102280';
 }
 
 # ABSTRACT: Base class for framework applications
@@ -80,7 +80,7 @@ sub run_app {
         $self->log->info('Application exception: %s', $E);
         $self->log->info('%s',                        $E->stacktrace);
 
-        # $self->delegate->set_rollback_mode;
+        $self->delegate->set_rollback_mode;
     };
     $self->app_finish;
 }
@@ -96,7 +96,7 @@ Class::Scaffold::App - Base class for framework applications
 
 =head1 VERSION
 
-version 1.101400
+version 1.102280
 
 =head1 SYNOPSIS
 
@@ -158,7 +158,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Class-Scaffold>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
@@ -174,11 +174,29 @@ and github infrastructure.
 
 =head1 AUTHORS
 
-  Marcel Gruenauer <marcel@cpan.org>
-  Florian Helmberger <fh@univie.ac.at>
-  Achim Adam <ac@univie.ac.at>
-  Mark Hofstetter <mh@univie.ac.at>
-  Heinz Ekker <ek@univie.ac.at>
+=over 4
+
+=item *
+
+Marcel Gruenauer <marcel@cpan.org>
+
+=item *
+
+Florian Helmberger <fh@univie.ac.at>
+
+=item *
+
+Achim Adam <ac@univie.ac.at>
+
+=item *
+
+Mark Hofstetter <mh@univie.ac.at>
+
+=item *
+
+Heinz Ekker <ek@univie.ac.at>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
