@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::Environment_TEST;
 BEGIN {
-  $Class::Scaffold::Environment_TEST::VERSION = '1.101400';
+  $Class::Scaffold::Environment_TEST::VERSION = '1.102280';
 }
 # ABSTRACT: Companion test class for the framework environment base class
 use Error::Hierarchy::Test 'throws2_ok';
@@ -31,7 +31,7 @@ Class::Scaffold::Environment_TEST - Companion test class for the framework envir
 
 =head1 VERSION
 
-version 1.101400
+version 1.102280
 
 =head1 INSTALLATION
 
@@ -42,7 +42,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Class-Scaffold>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
@@ -58,11 +58,29 @@ and github infrastructure.
 
 =head1 AUTHORS
 
-  Marcel Gruenauer <marcel@cpan.org>
-  Florian Helmberger <fh@univie.ac.at>
-  Achim Adam <ac@univie.ac.at>
-  Mark Hofstetter <mh@univie.ac.at>
-  Heinz Ekker <ek@univie.ac.at>
+=over 4
+
+=item *
+
+Marcel Gruenauer <marcel@cpan.org>
+
+=item *
+
+Florian Helmberger <fh@univie.ac.at>
+
+=item *
+
+Achim Adam <ac@univie.ac.at>
+
+=item *
+
+Mark Hofstetter <mh@univie.ac.at>
+
+=item *
+
+Heinz Ekker <ek@univie.ac.at>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
