@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::Exception::NoSuchFactoryHandler;
 BEGIN {
-  $Class::Scaffold::Exception::NoSuchFactoryHandler::VERSION = '1.101400';
+  $Class::Scaffold::Exception::NoSuchFactoryHandler::VERSION = '1.102280';
 }
 # ABSTRACT: Exception raised on a factory look-up failure
 use parent 'Class::Scaffold::Exception';
@@ -35,7 +35,7 @@ Class::Scaffold::Exception::NoSuchFactoryHandler - Exception raised on a factory
 
 =head1 VERSION
 
-version 1.101400
+version 1.102280
 
 =head1 INSTALLATION
 
@@ -46,7 +46,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Class-Scaffold>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
@@ -62,11 +62,29 @@ and github infrastructure.
 
 =head1 AUTHORS
 
-  Marcel Gruenauer <marcel@cpan.org>
-  Florian Helmberger <fh@univie.ac.at>
-  Achim Adam <ac@univie.ac.at>
-  Mark Hofstetter <mh@univie.ac.at>
-  Heinz Ekker <ek@univie.ac.at>
+=over 4
+
+=item *
+
+Marcel Gruenauer <marcel@cpan.org>
+
+=item *
+
+Florian Helmberger <fh@univie.ac.at>
+
+=item *
+
+Achim Adam <ac@univie.ac.at>
+
+=item *
+
+Mark Hofstetter <mh@univie.ac.at>
+
+=item *
+
+Heinz Ekker <ek@univie.ac.at>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
