@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::LazyString;
 BEGIN {
-  $Class::Scaffold::LazyString::VERSION = '1.101400';
+  $Class::Scaffold::LazyString::VERSION = '1.102280';
 }
 # ABSTRACT: Provides a string that is evaluated lazily
 use Exporter qw(import);
@@ -13,7 +13,7 @@ sub lazy_string { bless { code => shift }, 'Class::Scaffold::LazyString::Code' }
 
 package Class::Scaffold::LazyString::Code;
 BEGIN {
-  $Class::Scaffold::LazyString::Code::VERSION = '1.101400';
+  $Class::Scaffold::LazyString::Code::VERSION = '1.102280';
 }
 use overload '""' => sub { $_[0]->{code}->() };
 1;
@@ -28,7 +28,7 @@ Class::Scaffold::LazyString - Provides a string that is evaluated lazily
 
 =head1 VERSION
 
-version 1.101400
+version 1.102280
 
 =head1 METHODS
 
@@ -45,7 +45,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Class-Scaffold>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
@@ -61,11 +61,29 @@ and github infrastructure.
 
 =head1 AUTHORS
 
-  Marcel Gruenauer <marcel@cpan.org>
-  Florian Helmberger <fh@univie.ac.at>
-  Achim Adam <ac@univie.ac.at>
-  Mark Hofstetter <mh@univie.ac.at>
-  Heinz Ekker <ek@univie.ac.at>
+=over 4
+
+=item *
+
+Marcel Gruenauer <marcel@cpan.org>
+
+=item *
+
+Florian Helmberger <fh@univie.ac.at>
+
+=item *
+
+Achim Adam <ac@univie.ac.at>
+
+=item *
+
+Mark Hofstetter <mh@univie.ac.at>
+
+=item *
+
+Heinz Ekker <ek@univie.ac.at>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
