@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::YAML::Marshall::Constant;
 BEGIN {
-  $Class::Scaffold::YAML::Marshall::Constant::VERSION = '1.101400';
+  $Class::Scaffold::YAML::Marshall::Constant::VERSION = '1.102280';
 }
 # ABSTRACT: Marshalling plugin to get framework environment constants
 use YAML::Marshall 'constant';
@@ -28,7 +28,7 @@ Class::Scaffold::YAML::Marshall::Constant - Marshalling plugin to get framework
 
 =head1 VERSION
 
-version 1.101400
+version 1.102280
 
 =head1 METHODS
 
@@ -45,7 +45,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Class-Scaffold>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
@@ -61,11 +61,29 @@ and github infrastructure.
 
 =head1 AUTHORS
 
-  Marcel Gruenauer <marcel@cpan.org>
-  Florian Helmberger <fh@univie.ac.at>
-  Achim Adam <ac@univie.ac.at>
-  Mark Hofstetter <mh@univie.ac.at>
-  Heinz Ekker <ek@univie.ac.at>
+=over 4
+
+=item *
+
+Marcel Gruenauer <marcel@cpan.org>
+
+=item *
+
+Florian Helmberger <fh@univie.ac.at>
+
+=item *
+
+Achim Adam <ac@univie.ac.at>
+
+=item *
+
+Mark Hofstetter <mh@univie.ac.at>
+
+=item *
+
+Heinz Ekker <ek@univie.ac.at>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
