@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::YAML::Marshall::PID;
 BEGIN {
-  $Class::Scaffold::YAML::Marshall::PID::VERSION = '1.101400';
+  $Class::Scaffold::YAML::Marshall::PID::VERSION = '1.102280';
 }
 # ABSTRACT: Marshalling plugin to get the current process id
 use YAML::Marshall 'pid';
@@ -22,7 +22,7 @@ Class::Scaffold::YAML::Marshall::PID - Marshalling plugin to get the current pro
 
 =head1 VERSION
 
-version 1.101400
+version 1.102280
 
 =head1 METHODS
 
@@ -39,7 +39,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Class-Scaffold>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
@@ -55,11 +55,29 @@ and github infrastructure.
 
 =head1 AUTHORS
 
-  Marcel Gruenauer <marcel@cpan.org>
-  Florian Helmberger <fh@univie.ac.at>
-  Achim Adam <ac@univie.ac.at>
-  Mark Hofstetter <mh@univie.ac.at>
-  Heinz Ekker <ek@univie.ac.at>
+=over 4
+
+=item *
+
+Marcel Gruenauer <marcel@cpan.org>
+
+=item *
+
+Florian Helmberger <fh@univie.ac.at>
+
+=item *
+
+Achim Adam <ac@univie.ac.at>
+
+=item *
+
+Mark Hofstetter <mh@univie.ac.at>
+
+=item *
+
+Heinz Ekker <ek@univie.ac.at>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
